#!/bin/sh

# create initramfs image by using gen_cpio_init
# (we do not need root privileges for this!)
#
# see ./build.d/ to see how the content is created!

k_ver=`uname -r`
mod_origin=/lib/modules/$k_ver
outfile=/boot/initramfs-$k_ver.cpio.gz

usage() {
	cat <<-EOF
	$0 - create initramfs image by using gen_cpio_init

	$0 [ -r KERNEL_VERSION ] [ -m MODULES_DIR ] [ -o OUTPUT_FILE ]

	If no options are given the following defaults apply:
		$0 -r $k_ver -m $mod_origin -o $outfile

	Options:
		-r	Specify kernel version to use for modules dir
		-m	Specify directory where to search for kernel modules
		-o	Specify location of output file

	EOF
}


while [ ${#} -gt 0 ]
do
	case "$1" in
		-r)
			k_ver=$2
			shift ; shift
			;;
		-m)
			mod_origin=$2
			shift ; shift
			;;
		-o)
			outfile=$2
			shift ; shift
			;;
		*)
			usage
			exit 0
			;;
	esac
done


[ ${outfile:0:1} = "/" ] || outfile="`pwd`/$outfile"
[ ${mod_origin:0:1} = "/" ] || mod_origin="`pwd`/$mod_origin"

cat << EOF
kernel version: $k_ver
module origin: $mod_origin
output file: $outfile
EOF

export k_ver mod_origin

cd `dirname $0`

rm -fv list gen_init_cpio gen_init_cpio.o

# provide a tmpdir to our helpers
export TMPDIR="/tmp/irfs-`date +%s`.$$"
mkdir -pv $TMPDIR

# compile our list of cpio-content
./build-list.sh > list

# build helper
cc gen_init_cpio.c -o gen_init_cpio

# create and compress cpio archive
./gen_init_cpio list | gzip > $outfile

# remove the tmpdir
rm -rf $TMPDIR

# can be extracted with:
# gzip -dc ../irfs.cpio.gz | ( rm -rf ./root ; mkdir root ; cd root ; cpio -i -d -H newc --no-absolute-filenames )
